@ECHO OFF

REM  ICHECK Output Processor
REM
REM  Usage: CHECK outputfile [tempfile]
REM
REM   outputfile = file in which to save the list of changes
REM   tempfile   = file in which to store intermediary results (optional)
REM
REM  This batch file runs ICHECK, traps its output, and scans the output
REM  for the names of files that have been changed.  This simplifies the
REM  process of verifying files.
REM
REM  A temporary file is used to store the output from ICHECK.EXE.  The
REM  default name of this temporary file is ICHECK.$$$, but this may be
REM  overridden by specifying it as a second parameter when running
REM  CHECK.BAT or by creating an ICHECK environment variable.  For
REM  example:
REM
REM    SET ICHECK=F:\TEMP.ABC
REM 
REM  This program requires about 20 bytes of free environment space and
REM  DOS version 4.0 or greater.  The filter FIND.EXE, provided with DOS,
REM  is used and must be in the current path or drive/directory.  
REM
REM  Only the names of flagged files, not the directories, are saved.  This
REM  shouldn't be a problem since few, if any, files should ever be flagged.

ECHO 
ECHO ICHECK Output Processor
ECHO 

IF "%1" == "" GOTO Help
IF "%1" == "?" GOTO Help

set $ICHECK$=ICHECK.$$$
IF "%ICHECK%" == "" GOTO Skip1
set $ICHECK$=%ICHECK%
:Skip1

IF "%2" == "" GOTO Skip2
set $ICHECK$=%2
:Skip2

ECHO Testing integrity of files. Please stand by.

IF EXIST %1 del %1

icheck > %$ICHECK$%
IF ERRORLEVEL 255 GOTO Error
IF ERRORLEVEL 1 GOTO Modified

ECHO No changes to any files detected.
GOTO Finished

:Modified
ECHO Files have been modified. List saved to %1.
ECHO Files changed: > %1
find "size" < %$ICHECK$% >> %1
find "checksum" < %$ICHECK$% >> %1
find "error" < %$ICHECK$% >> %1
GOTO Finished

:Error
ECHO Error processing files.
ECHO ICHECK.EXE output saved in %$ICHECK$%.
GOTO Done

:Help
ECHO Usage: CHECK outputfile [tempfile]
ECHO 
ECHO   outputfile = file in which to save the list of changes
ECHO   tempfile   = file in which to store intermediary results (optional)
ECHO 
GOTO Done

:Finished
del %$ICHECK$%
set $ICHECK$=

:Done
PAUSE
