ECHO OFF

REM  ICHECK Output Processor
REM
REM  Usage: CHECK outputfile
REM
REM    outputfile = file in which to save the list of changes
REM
REM  This batch file runs ICHECK, traps its output, and scans the output
REM  for the names of files that have been changed.  This simplifies the
REM  process of verifying files.
REM
REM  The filter FIND.EXE, provided with DOS, is used and must be in the
REM  current path or drive/directory.  
REM
REM  Only the names of flagged files, not the directories, are saved.  This
REM  shouldn't be a problem since few, if any, files should ever be flagged.

ECHO 
ECHO ICHECK Output Processor
ECHO 

IF "%1" == "" GOTO Help
IF "%1" == "?" GOTO Help

ECHO Testing integrity of files. Please stand by.

IF EXIST %1 del %1

icheck > ICHECK.$$$
IF ERRORLEVEL 255 GOTO Error
IF ERRORLEVEL 1 GOTO Modified

ECHO No changes to any files detected.
GOTO Finished

:Modified
ECHO Files have been modified. List saved to %1.
ECHO Files changed: > %1
find "size" < ICHECK.$$$ >> %1
find "checksum" < ICHECK.$$$ >> %1
find "error" < ICHECK.$$$ >> %1
GOTO Finished

:Error
ECHO Error processing files.
ECHO ICHECK.EXE output saved in ICHECK.$$$.
GOTO Done

:Help
ECHO Usage: CHECK outputfile
ECHO 
ECHO   outputfile = file in which to save the list of changes
ECHO 
GOTO Done

:Finished
del ICHECK.$$$

:Done
PAUSE
